bean/com/sun/star/beans/LocalOfficeConnection.java                             
                       |    8 +-
 bean/com/sun/star/beans/LocalOfficeWindow.java                                 
                       |    8 +-
 bean/com/sun/star/beans/OfficeConnection.java                                  
                       |    2 
 bean/com/sun/star/beans/OfficeWindow.java                                      
                       |    4 -
 bean/com/sun/star/comp/beans/OfficeConnection.java                             
                       |    2 
 connectivity/source/drivers/mork/MResultSet.cxx                                
                       |    8 +-
 connectivity/source/drivers/mozab/MResultSet.cxx                               
                       |    8 +-
 extensions/source/ole/jscriptclasses.hxx                                       
                       |    2 
 forms/qa/integration/forms/FormControlTest.java                                
                       |    2 
 include/registry/registry.h                                                    
                       |   12 ++--
 odk/examples/DevelopersGuide/GUI/UnoDialogSample.java                          
                       |    2 
 qadevOOo/tests/java/mod/_sc/ScCellsEnumeration.java                            
                       |    2 
 qadevOOo/tests/java/mod/_sc/ScCellsObj.java                                    
                       |    2 
 qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java                                  
                       |    4 -
 qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java                                 
                       |    2 
 qadevOOo/tests/java/mod/_sc/ScViewPaneObj.java                                 
                       |    2 
 qadevOOo/tests/java/mod/_sd/SdLayerManager.java                                
                       |    2 
 qadevOOo/tests/java/mod/_sd/SdXShape.java                                      
                       |    4 -
 sal/qa/osl/file/osl_File.cxx                                                   
                       |    6 +-
 sal/qa/osl/security/osl_Security.cxx                                           
                       |   12 ++--
 
scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystem.java
         |    8 +-
 
scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystemBeanInfo.java
 |    6 +-
 shell/inc/internal/metainforeader.hxx                                          
                       |    4 -
 shell/source/win32/ooofilereader/metainforeader.cxx                            
                       |    4 -
 shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx                            
                       |    4 -
 sw/source/filter/ww8/writerhelper.hxx                                          
                       |   28 +++++-----
 xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx                    
                       |    6 +-
 27 files changed, 77 insertions(+), 77 deletions(-)

New commits:
commit be053c9a80ad237afc6da0b4174e1c7afc94ed92
Author: Tor Lillqvist <t...@collabora.com>
Date:   Fri Dec 20 23:24:56 2013 +0200

    Spelling correction: s/retrive/retrieve/
    
    Change-Id: I96845d358765e2d2507763a9b15a30388b32bc6b

diff --git a/bean/com/sun/star/beans/LocalOfficeConnection.java 
b/bean/com/sun/star/beans/LocalOfficeConnection.java
index b742fb3..9725017 100644
--- a/bean/com/sun/star/beans/LocalOfficeConnection.java
+++ b/bean/com/sun/star/beans/LocalOfficeConnection.java
@@ -136,7 +136,7 @@ public class LocalOfficeConnection
     }
 
     /**
-     * Retrives the UNO component context.
+     * Retrieves the UNO component context.
      * Establishes a connection if necessary and initialises the
      * UNO service manager if it has not already been initialised.
      * This method can return <code>null</code> if it fails to connect
@@ -304,7 +304,7 @@ public class LocalOfficeConnection
     }
 
     /**
-     * Retrives a path to the office program folder.
+     * Retrieves a path to the office program folder.
      *
      * @return The path to the office program folder.
      */
@@ -557,7 +557,7 @@ public class LocalOfficeConnection
         implements NativeService
     {
         /**
-         * Retrive the office service identifier.
+         * Retrieve the office service identifier.
          *
          * @return The identifier of the office service.
          */
@@ -595,7 +595,7 @@ public class LocalOfficeConnection
         }
 
         /**
-         * Retrives the ammount of time to wait for the startup.
+         * Retrieves the ammount of time to wait for the startup.
          *
          * @return The ammount of time to wait in seconds(?).
          */
diff --git a/bean/com/sun/star/beans/LocalOfficeWindow.java 
b/bean/com/sun/star/beans/LocalOfficeWindow.java
index 9388dcd..8f79b99 100644
--- a/bean/com/sun/star/beans/LocalOfficeWindow.java
+++ b/bean/com/sun/star/beans/LocalOfficeWindow.java
@@ -62,7 +62,7 @@ public class LocalOfficeWindow
     }
 
     /**
-     * Retrives an AWT component object associated with the OfficeWindow.
+     * Retrieves an AWT component object associated with the OfficeWindow.
      *
      * @return The AWT component object associated with the OfficeWindow.
      */
@@ -72,7 +72,7 @@ public class LocalOfficeWindow
     }
 
     /**
-     * Retrives an UNO XWindowPeer object associated with the OfficeWindow.
+     * Retrieves an UNO XWindowPeer object associated with the OfficeWindow.
      *
      * @return The UNO XWindowPeer object associated with the OfficeWindow.
      */
@@ -238,14 +238,14 @@ public class LocalOfficeWindow
     }
 
     /**
-     * Retrives a platform dependent system window identifier.
+     * Retrieves a platform dependent system window identifier.
      *
      * @return The system window identifier.
      */
     private native long getNativeWindow();
 
     /**
-     * Retrives a platform dependent system window type.
+     * Retrieves a platform dependent system window type.
      *
      * @return The system window type.
      */
diff --git a/bean/com/sun/star/beans/OfficeConnection.java 
b/bean/com/sun/star/beans/OfficeConnection.java
index 014c050..4301600 100644
--- a/bean/com/sun/star/beans/OfficeConnection.java
+++ b/bean/com/sun/star/beans/OfficeConnection.java
@@ -48,7 +48,7 @@ public interface OfficeConnection
     void setContainerFactory(ContainerFactory containerFactory);
 
     /**
-     * Retrives the UNO component context.
+     * Retrieves the UNO component context.
      * Establishes a connection if necessary and initialises the
      * UNO service manager if it has not already been initialised.
      *
diff --git a/bean/com/sun/star/beans/OfficeWindow.java 
b/bean/com/sun/star/beans/OfficeWindow.java
index 8fad77b..ebc46b8 100644
--- a/bean/com/sun/star/beans/OfficeWindow.java
+++ b/bean/com/sun/star/beans/OfficeWindow.java
@@ -31,14 +31,14 @@ import com.sun.star.awt.XWindowPeer;
 public interface OfficeWindow
 {
     /**
-     * Retrives an AWT component object associated with the OfficeWindow.
+     * Retrieves an AWT component object associated with the OfficeWindow.
      *
      * @return The AWT component object associated with the OfficeWindow.
      */
     Component getAWTComponent();
 
     /**
-     * Retrives an UNO XWindowPeer object associated with the OfficeWindow.
+     * Retrieves an UNO XWindowPeer object associated with the OfficeWindow.
      *
      * @return The UNO XWindowPeer object associated with the OfficeWindow.
      */
diff --git a/bean/com/sun/star/comp/beans/OfficeConnection.java 
b/bean/com/sun/star/comp/beans/OfficeConnection.java
index 71c74a3..2786810 100644
--- a/bean/com/sun/star/comp/beans/OfficeConnection.java
+++ b/bean/com/sun/star/comp/beans/OfficeConnection.java
@@ -49,7 +49,7 @@ public interface OfficeConnection
     void setContainerFactory(ContainerFactory containerFactory);
 
     /**
-     * Retrives the UNO component context.
+     * Retrieves the UNO component context.
      * Establishes a connection if necessary and initialises the
      * UNO service manager if it has not already been initialised.
      *
diff --git a/extensions/source/ole/jscriptclasses.hxx 
b/extensions/source/ole/jscriptclasses.hxx
index 606c238..3146318 100644
--- a/extensions/source/ole/jscriptclasses.hxx
+++ b/extensions/source/ole/jscriptclasses.hxx
@@ -36,7 +36,7 @@
 // "InitInOutParam"
 
 // If the object represents an out parameter then the value can after the call
-// be retrived by "Get".
+// be retrieved by "Get".
 
 // From JavaScript the functions Get, Set, InitOutParam and InitInOutParam are
 // used, that is they are accessible through IDispatch. The functions are used
diff --git a/forms/qa/integration/forms/FormControlTest.java 
b/forms/qa/integration/forms/FormControlTest.java
index 8d4ee1e..f591be4 100644
--- a/forms/qa/integration/forms/FormControlTest.java
+++ b/forms/qa/integration/forms/FormControlTest.java
@@ -491,7 +491,7 @@ public class FormControlTest extends 
complexlib.ComplexTestCase implements XSQLE
     }
 
     /* ------------------------------------------------------------------ */
-    /** retrives the control model with the given name
+    /** retrieves the control model with the given name
     */
     private XPropertySet getControlModel( String name ) throws 
com.sun.star.uno.Exception, java.lang.Exception
     {
diff --git a/include/registry/registry.h b/include/registry/registry.h
index 9caa133..b4add7f 100644
--- a/include/registry/registry.h
+++ b/include/registry/registry.h
@@ -240,11 +240,11 @@ REG_DLLPUBLIC RegError REGISTRY_CALLTYPE 
reg_getLongListValue(RegKeyHandle hKey,
 
 /** This function gets the string list value of a key.
 
-    @param[in]  hKey identifies a currently open key. The key whose value will 
be retrived by this
+    @param[in]  hKey identifies a currently open key. The key whose value will 
be retrieved by this
                  function is a subkey of the key identified by hKey.
     @param[in]  keyName points to a null terminated string specifying the name 
of a key whose value
-                    will be retrived. If keyName is NULL, then the value of 
the key specified by
-                    hKey will be retrived.
+                    will be retrieved. If keyName is NULL, then the value of 
the key specified by
+                    hKey will be retrieved.
     @param[out]  pValueList a Pointer to an ascii value list which returns the 
data of the value.
     @param[out]  pLen returns the length of the value list.
     @return REG_NO_ERROR if succeeds else an error code.
@@ -257,11 +257,11 @@ REG_DLLPUBLIC RegError REGISTRY_CALLTYPE 
reg_getStringListValue(RegKeyHandle hKe
 
 /** This function gets the unicode list value of a key.
 
-    @param[in]  hKey identifies a currently open key. The key whose value will 
be retrived by this
+    @param[in]  hKey identifies a currently open key. The key whose value will 
be retrieved by this
                  function is a subkey of the key identified by hKey.
     @param[in]  keyName points to a null terminated string specifying the name 
of a key whose value
-                    will be retrived. If keyName is NULL, then the value of 
the key specified by
-                    hKey will be retrived.
+                    will be retrieved. If keyName is NULL, then the value of 
the key specified by
+                    hKey will be retrieved.
     @param[out]  pValueList a Pointer to an unicode value list which returns 
the data of the value.
     @param[out]  pLen returns the length of the value list.
     @return REG_NO_ERROR if succeeds else an error code.
diff --git a/odk/examples/DevelopersGuide/GUI/UnoDialogSample.java 
b/odk/examples/DevelopersGuide/GUI/UnoDialogSample.java
index 61c37d6..e697995 100644
--- a/odk/examples/DevelopersGuide/GUI/UnoDialogSample.java
+++ b/odk/examples/DevelopersGuide/GUI/UnoDialogSample.java
@@ -217,7 +217,7 @@ public class UnoDialogSample implements XTextListener, 
XSpinListener, XActionLis
     public String getImageUrl(String _sRegistryPath, String _sImageName) {
         String sImageUrl = "";
         try {
-            // retrive the configuration node of the extension
+            // retrieve the configuration node of the extension
             XNameAccess xNameAccess = getRegistryKeyContent(_sRegistryPath);
             if (xNameAccess != null){
                 if (xNameAccess.hasByName(_sImageName)){
diff --git a/qadevOOo/tests/java/mod/_sc/ScCellsEnumeration.java 
b/qadevOOo/tests/java/mod/_sc/ScCellsEnumeration.java
index 0b30d84..f811655 100644
--- a/qadevOOo/tests/java/mod/_sc/ScCellsEnumeration.java
+++ b/qadevOOo/tests/java/mod/_sc/ScCellsEnumeration.java
@@ -85,7 +85,7 @@ public class ScCellsEnumeration extends TestCase {
     * Creating a Testenvironment for the interfaces to be tested.
     * Retrieves a collection of spreadsheets from a document
     * and takes one of them. Replaces text of some cells.
-    * Retrives a cell range of the visible cells using the interface
+    * Retrieves a cell range of the visible cells using the interface
     * <code>XCellRangesQuery</code>. Retrieves a collection of cells from
     * this cell range and creates it's enumeration using the interface
     * <code>XEnumerationAccess</code>.The created enumeration is the instance
diff --git a/qadevOOo/tests/java/mod/_sc/ScCellsObj.java 
b/qadevOOo/tests/java/mod/_sc/ScCellsObj.java
index 0ee2b1e..a22119f 100644
--- a/qadevOOo/tests/java/mod/_sc/ScCellsObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScCellsObj.java
@@ -89,7 +89,7 @@ public class ScCellsObj extends TestCase {
     * Creating a Testenvironment for the interfaces to be tested.
     * Retrieves a collection of spreadsheets from a document,
     * and takes one of them. Replaces text of some cells.
-    * Retrives a cell range of the visible cells using the interface
+    * Retrieves a cell range of the visible cells using the interface
     * <code>XCellRangesQuery</code>. Retrieves a collection of cells from
     * this cell range, this collection is instance of the service
     * <code>com.sun.star.sheet.Cells</code>.
diff --git a/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java 
b/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
index f669f38..b987830 100644
--- a/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
@@ -100,8 +100,8 @@ public class ScDDELinkObj extends TestCase {
     * spreadsheets from a document and takes one of them. Sets specific formula
     * to some cells in the spreadsheet(the formula specify DDE links to the
     * testdocument). Retrieves the collection of DDE links in the document and
-    * retrives first DDE link from the collection.
-    * The retrived DDE link is the instance of the service
+    * retrieves first DDE link from the collection.
+    * The retrieved DDE link is the instance of the service
     * <code>com.sun.star.sheet.DDELink</code>.
     * Object relations created :
     * <ul>
diff --git a/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java 
b/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
index e00da23..b9af713 100644
--- a/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
@@ -97,7 +97,7 @@ public class ScDDELinksObj extends TestCase {
     * spreadsheets from a document and takes one of them. Sets specific formula
     * to some cells in the spreadsheet(the formula specify DDE links to the
     * testdocument). Retrieves the collection of DDE links in the document.
-    * The retrived collection of DDE link is the instance of the service
+    * The retrieved collection of DDE link is the instance of the service
     * <code>com.sun.star.sheet.DDELinks</code>.
     * @see com.sun.star.frame.Desktop
     * @see com.sun.star.sheet.DDELinks
diff --git a/qadevOOo/tests/java/mod/_sc/ScViewPaneObj.java 
b/qadevOOo/tests/java/mod/_sc/ScViewPaneObj.java
index b96da02..74ab48f 100644
--- a/qadevOOo/tests/java/mod/_sc/ScViewPaneObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScViewPaneObj.java
@@ -97,7 +97,7 @@ public class ScViewPaneObj extends TestCase {
      * Retieves the current controller of the spreadsheet document using the
      * interface <code>XModel</code>. The controller contains the collection
      * of the view panes so retrieves the view pane with index 0 from
-     * the collection. The retrived view pane is the instance of the service
+     * the collection. The retrieved view pane is the instance of the service
      * <code>com.sun.star.sheet.SpreadsheetViewPane</code>. Retrieves the 
address
      * of the cell range that consists of the cells which are visible in the 
pane.
      * Object relations created :
diff --git a/qadevOOo/tests/java/mod/_sd/SdLayerManager.java 
b/qadevOOo/tests/java/mod/_sd/SdLayerManager.java
index 1ceca52..a80e887 100644
--- a/qadevOOo/tests/java/mod/_sd/SdLayerManager.java
+++ b/qadevOOo/tests/java/mod/_sd/SdLayerManager.java
@@ -101,7 +101,7 @@ public class SdLayerManager extends TestCase {
     *      {@link ifc.drawing._XLayerManager}(the created shape)</li>
     *  <li> <code>'Shapes'</code> for
     *      {@link ifc.drawing._XLayerManager}(the shape collection of
-    *      the retrived draw page)</li>
+    *      the retrieved draw page)</li>
     * </ul>
     * @see com.sun.star.drawing.XLayerSupplier
     * @see com.sun.star.drawing.LayerManager
diff --git a/qadevOOo/tests/java/mod/_sd/SdXShape.java 
b/qadevOOo/tests/java/mod/_sd/SdXShape.java
index c5a78d4..c342c8c 100644
--- a/qadevOOo/tests/java/mod/_sd/SdXShape.java
+++ b/qadevOOo/tests/java/mod/_sd/SdXShape.java
@@ -103,11 +103,11 @@ public class SdXShape extends TestCase {
     * <ul>
     *  <li> <code>'Style1'</code> for
     *      {@link ifc.drawing._XShapeDescriptor}, {@link ifc.drawing._XShape}
-    *      (the value of the property 'Style' that was retrived from the 
created
+    *      (the value of the property 'Style' that was retrieved from the 
created
     *      rectangle shape) </li>
     *  <li> <code>'Style2'</code> for
     *      {@link ifc.drawing._XShapeDescriptor}, {@link ifc.drawing._XShape}
-    *      (the value of the property 'Style' that was retrived from the 
created
+    *      (the value of the property 'Style' that was retrieved from the 
created
     *      ellipse shape) </li>
     * </ul>
     * @see com.sun.star.drawing.XDrawPagesSupplier
diff --git a/sal/qa/osl/file/osl_File.cxx b/sal/qa/osl/file/osl_File.cxx
index 11ce5ec..1da398a 100644
--- a/sal/qa/osl/file/osl_File.cxx
+++ b/sal/qa/osl/file/osl_File.cxx
@@ -5579,7 +5579,7 @@ namespace osl_Directory
             nError1 = testDirectory.close();
             CPPUNIT_ASSERT( ::osl::FileBase::E_None == nError1 );
 
-            CPPUNIT_ASSERT_MESSAGE( "test for getNextItem function: retrive 
three items and check their names.",
+            CPPUNIT_ASSERT_MESSAGE( "test for getNextItem function: retrieve 
three items and check their names.",
                                     ( sal_True == bOk1 ) && ( sal_True == bOk2 
) && ( sal_True == bOk3 ) );
         }
 
@@ -5588,7 +5588,7 @@ namespace osl_Directory
              ::osl::Directory testDirectory( aTmpName3 ); //constructor
             nError1 = testDirectory.getNextItem( rItem );
 
-            CPPUNIT_ASSERT_MESSAGE( "test for getNextItem function: retrive an 
item in a directory which is not opened, also test for nHint's default value.",
+            CPPUNIT_ASSERT_MESSAGE( "test for getNextItem function: retrieve 
an item in a directory which is not opened, also test for nHint's default 
value.",
                                     ( ::osl::FileBase::E_INVAL == nError1 ) );
         }
 
@@ -5609,7 +5609,7 @@ namespace osl_Directory
             nError1 = testDirectory.close();
             CPPUNIT_ASSERT( ::osl::FileBase::E_None == nError1 );
 
-            CPPUNIT_ASSERT_MESSAGE( "test for getNextItem function: retrive 4 
times in a directory which contain only 3 files.",
+            CPPUNIT_ASSERT_MESSAGE( "test for getNextItem function: retrieve 4 
times in a directory which contain only 3 files.",
                                     ( ::osl::FileBase::E_NOENT == nError2 ) );
         }
 
diff --git a/sal/qa/osl/security/osl_Security.cxx 
b/sal/qa/osl/security/osl_Security.cxx
index 6fb065a..f24d404 100644
--- a/sal/qa/osl/security/osl_Security.cxx
+++ b/sal/qa/osl/security/osl_Security.cxx
@@ -583,35 +583,35 @@ void MyTestPlugInImpl::initialize( 
CPPUNIT_NS::TestFactoryRegistry *,
 #endif
 
     /// print the information.
-    t_print("#\n#Retrived system information is below:\n");
+    t_print("#\n#Retrieved system information is below:\n");
 
     t_print("Computer Name:              ");
     if ( strComputerName.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strComputerName );
 
     t_print("Current User Name:          ");
     if ( strUserName.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strUserName );
 
     t_print("Current User Home Directory:");
     if ( strHomeDirectory.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strHomeDirectory );
 
     t_print("Current Config Directory:   ");
     if ( strConfigDirectory.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strConfigDirectory );
 
     t_print("Current UserID:             ");
     if ( strUserID.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strUserID );
 
diff --git 
a/scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystem.java
 
b/scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystem.java
index c6c55d5..ffb4a5f 100644
--- 
a/scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystem.java
+++ 
b/scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystem.java
@@ -149,7 +149,7 @@ public class OpenOfficeDocFileSystem
     }
 
     /**
-     * Retrives the 'document' property.
+     * Retrieves the 'document' property.
      */
     public File getDocument()
     {
@@ -200,7 +200,7 @@ System.out.println("    exception: " + ioe.getMessage());
     }
 
     /**
-     * Retrives 'readonly' property.
+     * Retrieves 'readonly' property.
      * NOTE: The portion of the mounted document available to the user is
      *       always editable.
      */
@@ -436,7 +436,7 @@ System.out.println("    exception: " + ioe.getMessage());
     }
 
     /*
-     * Retrives or creates a file.
+     * Retrieves or creates a file.
      */
     private Entry getFileEntry(String name)
         throws IOException
@@ -462,7 +462,7 @@ System.out.println("    exception: " + ioe.getMessage());
     }
 
     /*
-     * Retrives or creates a folder.
+     * Retrieves or creates a folder.
      */
     private Entry getFolderEntry(String name)
         throws IOException
diff --git 
a/scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystemBeanInfo.java
 
b/scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystemBeanInfo.java
index 4ec0f0b..4e4b8fb 100644
--- 
a/scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystemBeanInfo.java
+++ 
b/scripting/java/org/openoffice/netbeans/modules/office/filesystem/OpenOfficeDocFileSystemBeanInfo.java
@@ -41,7 +41,7 @@ public class OpenOfficeDocFileSystemBeanInfo
         ICONLOCATION + File.separator + "OpenOfficeDocFileSystemIcon32.png";
 
     /**
-     * Retrives an additional bean information.
+     * Retrieves an additional bean information.
      */
     public BeanInfo[] getAdditionalBeanInfo()
     {
@@ -64,7 +64,7 @@ public class OpenOfficeDocFileSystemBeanInfo
     }
 */
     /**
-     * Retrives bean property descriptors.
+     * Retrieves bean property descriptors.
      */
     public PropertyDescriptor[] getPropertyDescriptors()
     {
@@ -99,7 +99,7 @@ public class OpenOfficeDocFileSystemBeanInfo
     }
 
     /**
-     * Retrives an icon by the icon type.
+     * Retrieves an icon by the icon type.
      */
     public Image getIcon(int type)
     {
diff --git a/shell/inc/internal/metainforeader.hxx 
b/shell/inc/internal/metainforeader.hxx
index 7365d18..b9f86fd 100644
--- a/shell/inc/internal/metainforeader.hxx
+++ b/shell/inc/internal/metainforeader.hxx
@@ -41,7 +41,7 @@ public:
     /** check if the Tag is in the target meta.xml file.
 
         @param TagName
-        the name of the tag that will be retrive.
+        the name of the tag that will be retrieved.
     */
     bool hasTag(std::wstring TagName) const;
 
@@ -49,7 +49,7 @@ public:
     /** Get a specific tag content, compound tags will be returned as comma 
separated list.
 
         @param TagName
-        the name of the tag that will be retrive.
+        the name of the tag that will be retrieved.
     */
     std::wstring getTagData( const std::wstring& TagName);
 
diff --git a/shell/source/win32/ooofilereader/metainforeader.cxx 
b/shell/source/win32/ooofilereader/metainforeader.cxx
index 75bca87..9edecc9 100644
--- a/shell/source/win32/ooofilereader/metainforeader.cxx
+++ b/shell/source/win32/ooofilereader/metainforeader.cxx
@@ -130,7 +130,7 @@ CMetaInfoReader::~CMetaInfoReader( void )
 /** check if the Tag is in the target meta.xml file.
 
     @param TagName
-    the name of the tag that will be retrive.
+    the name of the tag that will be retrieve.
 */
 bool CMetaInfoReader::hasTag( std::wstring TagName ) const
 {
@@ -140,7 +140,7 @@ bool CMetaInfoReader::hasTag( std::wstring TagName ) const
 /** Get a specific tag content, compound tags will be returned as comma 
separated list.
 
     @param TagName
-    the name of the tag that will be retrive.
+    the name of the tag that will be retrieve.
 */
 std::wstring CMetaInfoReader::getTagData( const std::wstring& TagName)
 {
diff --git a/shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx 
b/shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx
index 94df159..6fd350b 100644
--- a/shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx
+++ b/shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx
@@ -141,8 +141,8 @@ private:
     virtual ~COooFilter();
 
     long                      m_lRefs;                  // Reference count
-    CContentReader *          m_pContentReader;         // A content reader 
that retrive document content.
-    CMetaInfoReader *         m_pMetaInfoReader;        // A metainfo reader 
that retrive document metainfo.
+    CContentReader *          m_pContentReader;         // A content reader 
that retrieves document content.
+    CMetaInfoReader *         m_pMetaInfoReader;        // A metainfo reader 
that retrieves document metainfo.
     FilterState               m_eState;                 // State of filtering
     ::std::wstring            m_pwszFileName;           // Name of input file 
to filter
     ULONG                     m_ulUnicodeBufferLen;     // UNICODE Characters 
read from file to chunk buffer
diff --git a/sw/source/filter/ww8/writerhelper.hxx 
b/sw/source/filter/ww8/writerhelper.hxx
index e026ca5..88e6e88 100644
--- a/sw/source/filter/ww8/writerhelper.hxx
+++ b/sw/source/filter/ww8/writerhelper.hxx
@@ -274,8 +274,8 @@ namespace sw
             and receiving a SfxPoolItem reference which must then typically be
             cast back to its original type which is both tedious and verbose.
 
-            ItemGet uses item_cast () on the retrived reference to test that 
the
-            retrived property is of the type that the developer thinks it is.
+            ItemGet uses item_cast () on the retrieved reference to test that 
the
+            retrieved property is of the type that the developer thinks it is.
 
             @param rNode
             The SwCntntNode to retrieve the property from
@@ -305,8 +305,8 @@ namespace sw
             and receiving a SfxPoolItem reference which must then typically be
             cast back to its original type which is both tedious and verbose.
 
-            ItemGet uses item_cast () on the retrived reference to test that 
the
-            retrived property is of the type that the developer thinks it is.
+            ItemGet uses item_cast () on the retrieved reference to test that 
the
+            retrieved property is of the type that the developer thinks it is.
 
             @param rFmt
             The SwFmt to retrieve the property from
@@ -334,8 +334,8 @@ namespace sw
             and receiving a SfxPoolItem reference which must then typically be
             cast back to its original type which is both tedious and verbose.
 
-            ItemGet uses item_cast () on the retrived reference to test that 
the
-            retrived property is of the type that the developer thinks it is.
+            ItemGet uses item_cast () on the retrieved reference to test that 
the
+            retrieved property is of the type that the developer thinks it is.
 
             @param rSet
             The SfxItemSet to retrieve the property from
@@ -368,8 +368,8 @@ namespace sw
             DefaultItemGet returns a reference to the default property of a
             given SfxItemPool for a given property id, e.g. default fontsize
 
-            DefaultItemGet uses item_cast () on the retrived reference to test
-            that the retrived property is of the type that the developer thinks
+            DefaultItemGet uses item_cast () on the retrieved reference to test
+            that the retrieved property is of the type that the developer 
thinks
             it is.
 
             @param rPool
@@ -404,8 +404,8 @@ namespace sw
             given SwDoc (Writer Document) for a given property id, e.g default
             fontsize
 
-            DefaultItemGet uses item_cast () on the retrived reference to test
-            that the retrived property is of the type that the developer thinks
+            DefaultItemGet uses item_cast () on the retrieved reference to test
+            that the retrieved property is of the type that the developer 
thinks
             it is.
 
             @param rPool
@@ -441,8 +441,8 @@ namespace sw
             property id if it exists in the SfxItemSet or its chain of parents,
             e.g. fontsize
 
-            HasItem uses item_cast () on the retrived pointer to test that the
-            retrived property is of the type that the developer thinks it is.
+            HasItem uses item_cast () on the retrieved pointer to test that the
+            retrieved property is of the type that the developer thinks it is.
 
             @param rSet
             The SfxItemSet whose property we want
@@ -474,8 +474,8 @@ namespace sw
             HasItem returns a pointer to the requested SfxPoolItem for a given
             property id if it exists in the SwFmt e.g. fontsize
 
-            HasItem uses item_cast () on the retrived pointer to test that the
-            retrived property is of the type that the developer thinks it is.
+            HasItem uses item_cast () on the retrieved pointer to test that the
+            retrieved property is of the type that the developer thinks it is.
 
             @param rSet
             The SwFmt whose property we want
diff --git a/xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx 
b/xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx
index ee3eb88..082a5aa 100644
--- a/xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx
+++ b/xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx
@@ -390,7 +390,7 @@ OString XMLDocumentWrapper_XmlSecImpl::getNodeQName(const 
xmlNodePtr pNode) cons
 /****** XMLDocumentWrapper_XmlSecImpl/getNodeQName ****************************
  *
  *   NAME
- *  getNodeQName -- Retrives the qualified name of a node
+ *  getNodeQName -- Retrieves the qualified name of a node
  *
  *   SYNOPSIS
  *  name = getNodeQName(pNode);
@@ -399,7 +399,7 @@ OString XMLDocumentWrapper_XmlSecImpl::getNodeQName(const 
xmlNodePtr pNode) cons
  *  see NAME
  *
  *   INPUTS
- *  pNode - the node whose name will be retrived
+ *  pNode - the node whose name will be retrieved
  *
  *   RESULT
  *  name - the node's qualified name
@@ -428,7 +428,7 @@ xmlNodePtr XMLDocumentWrapper_XmlSecImpl::checkElement( 
const cssu::Reference< c
 /****** XMLDocumentWrapper_XmlSecImpl/checkElement ****************************
  *
  *   NAME
- *  checkElement -- Retrives the node wrapped by an XXMLElementWrapper
+ *  checkElement -- Retrieves the node wrapped by an XXMLElementWrapper
  *  interface
  *
  *   SYNOPSIS
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to
diff --git a/connectivity/source/drivers/mork/MResultSet.cxx 
b/connectivity/source/drivers/mork/MResultSet.cxx
index 99f7275..5ccb98d 100644
--- a/connectivity/source/drivers/mork/MResultSet.cxx
+++ b/connectivity/source/drivers/mork/MResultSet.cxx
@@ -1499,7 +1499,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
nOffset )
         m_pStatement->getOwnConnection()->throwSQLException( 
STR_ILLEGAL_MOVEMENT, *this );
 
     sal_Int32  nNumberOfRecords = m_aQueryHelper.getResultCount();
-    sal_Int32  nRetrivedRows = currentRowCount();
+    sal_Int32  nRetrievedRows = currentRowCount();
     sal_Int32  nCurPos = m_nRowPos;
 
     OSL_TRACE("seekRow: nCurPos = %d", nCurPos );
@@ -1521,7 +1521,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
nOffset )
 
         case LAST_POS:
             OSL_TRACE("seekRow: LAST");
-            nCurPos = nRetrivedRows;
+            nCurPos = nRetrievedRows;
             break;
         case ABSOLUTE_POS:
             OSL_TRACE("seekRow: ABSOLUTE : %d", nOffset);
@@ -1543,7 +1543,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
nOffset )
     {
         nCurCard = (m_pKeySet->get())[nCurPos-1];
     }
-    else    //The requested row has not been retrived until now. We should get 
the right card for it.
+    else    //The requested row has not been retrieved until now. We should 
get the right card for it.
         nCurCard = nCurPos + deletedCount();
 
     if ( nCurCard > nNumberOfRecords) {
@@ -1552,7 +1552,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
nOffset )
         OSL_TRACE("seekRow: return False, m_nRowPos = %u", m_nRowPos );
         return sal_False;
     }
     //Insert new retrived items for later use
     fillKeySet(nNumberOfRecords);
     m_nRowPos = (sal_uInt32)nCurPos;
     OSL_TRACE("seekRow: return True, m_nRowPos = %u", m_nRowPos );
@@ -1552,7 +1552,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
         return sal_False;
     }
-    //Insert new retrived items for later use
+    //Insert new retrieved items for later use
     fillKeySet(nNumberOfRecords);
     m_nRowPos = (sal_uInt32)nCurPos;
diff --git a/connectivity/source/drivers/mozab/MResultSet.cxx 
b/connectivity/source/drivers/mozab/MResultSet.cxx
index d0e449e..aeb5bea 100644
--- a/connectivity/source/drivers/mozab/MResultSet.cxx
+++ b/connectivity/source/drivers/mozab/MResultSet.cxx
@@ -1491,7 +1491,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
nOffset )
         m_pStatement->getOwnConnection()->throwSQLException( 
STR_ILLEGAL_MOVEMENT, *this );
 
     sal_Int32  nNumberOfRecords = m_aQuery.getRealRowCount();
-    sal_Int32  nRetrivedRows = currentRowCount();
+    sal_Int32  nRetrievedRows = currentRowCount();
     sal_Int32  nCurPos = m_nRowPos;
 
     OSL_TRACE("seekRow: nCurPos = %d", nCurPos );
@@ -1513,7 +1513,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
nOffset )
 
         case LAST_POS:
             OSL_TRACE("seekRow: LAST");
-            nCurPos = nRetrivedRows;
+            nCurPos = nRetrievedRows;
             break;
         case ABSOLUTE_POS:
             OSL_TRACE("seekRow: ABSOLUTE : %d", nOffset);
@@ -1535,7 +1535,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
nOffset )
     {
         nCurCard = (m_pKeySet->get())[nCurPos-1];
     }
-    else    //The requested row has not been retrived until now. We should get 
the right card for it.
+    else    //The requested row has not been retrieved until now. We should 
get the right card for it.
         nCurCard = nCurPos + deletedCount();
 
     while ( nCurCard > nNumberOfRecords && !m_aQuery.queryComplete() ) {
@@ -1553,7 +1553,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
nOffset )
         OSL_TRACE("seekRow: return False, m_nRowPos = %u", m_nRowPos );
         return sal_False;
     }
     //Insert new retrived items for later use
     fillKeySet(nNumberOfRecords);
     m_nRowPos = (sal_uInt32)nCurPos;
     OSL_TRACE("seekRow: return True, m_nRowPos = %u", m_nRowPos );
@@ -1553,7 +1553,7 @@ sal_Bool OResultSet::seekRow( eRowPosition pos, sal_Int32 
         return sal_False;
     }
-    //Insert new retrived items for later use
+    //Insert new retrieved items for later use
     fillKeySet(nNumberOfRecords);
     m_nRowPos = (sal_uInt32)nCurPos;